==> rust_like_result-2.2.1.tar.gz: test/result_test.dart <==
import 'dart:io';

import 'package:rust_like_result/rust_like_result.dart';
import 'package:test/test.dart';

void main() {
  late Result<String> good;
  late Err<String> bad;

  setUp(() {
    good = Ok('Good result');
    bad = Err(ArgumentError('Bad argument AAA'));
  });

  // good:
  test('good.isOk return true', () => expect(good.isOk, isTrue));
  test('good.isErr return false', () => expect(good.isErr, isFalse));
  test('ok is Ok type', () => expect(good, isA<Ok>()));
  test('ok is not Err type', () => expect(good, isNot(Err)));
  test('good val is String', () => expect(good.val, isA<String>()));
  test('good err is an null', () => expect(good.err, null));
  test('good can be unwraped to value',
      () => expect(good.unwrap, equals('Good result')));
  test('good unwrapOrDefault return val',
      () => expect(good.unwrapOrDefault('MyDefault'), 'Good result'));
  test('good unwrapOrElse returns value',
      () => expect(good.unwrapOrElse((e) => 'Hi!'), 'Good result'));

  // bad:
  test('bad.isOk return false', () => expect(bad.isOk, isFalse));
  test('bad.isErr return true', () => expect(bad.isErr, isTrue));
  test('bad is not Ok type', () => expect(bad, isNot(Ok)));
  test('bad is Err type', () => expect(bad, isA<Err>()));
  test('bad throws error while unwrap',
      () => expect(() => bad.unwrap, throwsArgumentError));
  test('bad val is null', () => expect(bad.val, null));
  test('bad err is Error', () => expect(bad.err, isA<Error>()));
  test('bad unwrapOrDefault return default',
      () => expect(bad.unwrapOrDefault('Bad value here'), 'Bad value here'));
  test('bad unwrapOrElse returns call result',
      () => expect(bad.unwrapOrElse((e) => 'Other val'), 'Other val'));

  test(
      'tryAsResultAsync returns Futire<Err> on exception',
      () async => expect(
          await tryAsResultAsync(
            () => File('notExistsFile').rename('newPath'),
          ),
          isA<Err>()));
  test(
      'tryAsResultAsync returns Future<Ok> on success',
      () async => expect(
          await tryAsResultAsync(
            () => Directory('.').list(),
          ),
          isA<Ok>()));

  test(
      'tryAsResultSync returns Futire<Err> on exception',
      () => expect(
          tryAsResultSync(
            () => File('notExistsFile').renameSync('newPath'),
          ),
          isA<Err>()));
  test(
      'tryAsResultSync returns Future<Ok> on success',
      () => expect(
          tryAsResultSync(
            () => Directory('.').listSync(),
          ),
          isA<Ok>()));

  test(
      'testResult return Ok on success',
      () => expect(
          testResult((Result r) => r.val > 2, Ok(3), 'not more then 2'),
          isA<Ok>()));

  test(
      'testResult return Err on fail',
      () => expect(
          testResult((Result r) => r.val > 2, Ok(1), 'not more then 2'),
          isA<Err>()));

  test('Result Err piping',
      () => expect(Err(ArgumentError('Bad value')) | (v) => v * 2, isA<Err>()));

  test(
      'Result Err piping',
      () => expect(
          Ok(123) | (((v) => v * 2) as dynamic Function(int?)), isA<Ok>()));

  test('Replace err with new value by replacePossibleErrorWith', () {
    var oldErr = Err(ArgumentError('Old'));
    var newErr = oldErr.replacePossibleErrorWith(ArgumentError('New'));
    expect(newErr.err.toString(), equals('Invalid argument(s): New'));
  });

  test('Replace err with new value by replacePossibleError', () {
    var oldErr = Err(ArgumentError('Old'))
        .replacePossibleError((old) => ArgumentError('New'));
    var newErr = oldErr.replacePossibleError((old) => ArgumentError('New'));
    expect(newErr.err.toString(), equals('Invalid argument(s): New'));
  });
}

==> rust_like_result-2.3.0.tar.gz: test/result_test.dart <==
import 'dart:io';

import 'package:rust_like_result/rust_like_result.dart';
import 'package:test/test.dart';

void main() {
  late Result<String> good;
  late Err<String> bad;

  setUp(() {
    good = Ok('Good result');
    bad = Err(ArgumentError('Bad argument AAA'));
  });

  // good:
  test('good.isOk return true', () => expect(good.isOk, isTrue));
  test('good.isErr return false', () => expect(good.isErr, isFalse));
  test('ok is Ok type', () => expect(good, isA<Ok>()));
  test('ok is not Err type', () => expect(good, isNot(Err)));
  test('good val is String', () => expect(good.val, isA<String>()));
  test('good err is an null', () => expect(good.err, null));
  test('good can be unwraped to value',
      () => expect(good.unwrap, equals('Good result')));
  test('good unwrapOrDefault return val',
      () => expect(good.unwrapOrDefault('MyDefault'), 'Good result'));
  test('good unwrapOrElse returns value',
      () => expect(good.unwrapOrElse((e) => 'Hi!'), 'Good result'));

  // bad:
  test('bad.isOk return false', () => expect(bad.isOk, isFalse));
  test('bad.isErr return true', () => expect(bad.isErr, isTrue));
  test('bad is not Ok type', () => expect(bad, isNot(Ok)));
  test('bad is Err type', () => expect(bad, isA<Err>()));
  test('bad throws error while unwrap',
      () => expect(() => bad.unwrap, throwsArgumentError));
  test('bad val is null', () => expect(bad.val, null));
  test('bad err is Error', () => expect(bad.err, isA<Error>()));
  test('bad unwrapOrDefault return default',
      () => expect(bad.unwrapOrDefault('Bad value here'), 'Bad value here'));
  test('bad unwrapOrElse returns call result',
      () => expect(bad.unwrapOrElse((e) => 'Other val'), 'Other val'));

  test(
      'tryAsResultAsync returns Futire<Err> on exception',
      () async => expect(
          await tryAsResultAsync(
            () => File('notExistsFile').rename('newPath'),
          ),
          isA<Err>()));
  test(
      'tryAsResultAsync returns Future<Ok> on success',
      () async => expect(
          await tryAsResultAsync(
            () => Directory('.').list(),
          ),
          isA<Ok>()));

  test(
      'tryAsResultSync returns Futire<Err> on exception',
      () => expect(
          tryAsResultSync(
            () => File('notExistsFile').renameSync('newPath'),
          ),
          isA<Err>()));
  test(
      'tryAsResultSync returns Future<Ok> on success',
      () => expect(
          tryAsResultSync(
            () => Directory('.').listSync(),
          ),
          isA<Ok>()));

  test(
      'testResult return Ok on success',
      () => expect(
          testResult((Result r) => r.val > 2, Ok(3), 'not more then 2'),
          isA<Ok>()));

  test(
      'testResult return Err on fail',
      () => expect(
          testResult((Result r) => r.val > 2, Ok(1), 'not more then 2'),
          isA<Err>()));

  test('Result Err piping',
      () => expect(Err(ArgumentError('Bad value')) | (v) => v * 2, isA<Err>()));

  test(
      'Result Err piping',
      () => expect(
          Ok(123) | (((v) => v * 2)), isA<Ok>()));

  test('Replace err with new value by replacePossibleErrorWith', () {
    var oldErr = Err(ArgumentError('Old'));
    var newErr = oldErr.replacePossibleErrorWith(ArgumentError('New'));
    expect(newErr.err.toString(), equals('Invalid argument(s): New'));
  });

  test('Replace err with new value by replacePossibleError', () {
    var oldErr = Err(ArgumentError('Old'))
        .replacePossibleError((old) => ArgumentError('New'));
    var newErr = oldErr.replacePossibleError((old) => ArgumentError('New'));
    expect(newErr.err.toString(), equals('Invalid argument(s): New'));
  });
}
